"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMongoCollection = void 0;
const get_mongo_db_1 = require("./get-mongo-db");
const is_mongo_definition_1 = require("./helpers/is-mongo-definition");
/**
 * @description Init mongodb collection
 *
 * @export
 * @param {(mongodb.Collection | undefined)} dbCollection Saved connection
 * @param {IMongoAppenderConfiguration} config Configuration to mongo
 * @return {*}  {Promise<mongodb.Collection>}
 */
function getMongoCollection(dbCollection, config) {
    return __awaiter(this, void 0, void 0, function* () {
        if (dbCollection) {
            return dbCollection;
        }
        else if (config) {
            if ((0, is_mongo_definition_1.isMongoDefinition)(config.mongoSetting)) {
                const db = yield (0, get_mongo_db_1.getMongoDb)(config.mongoSetting);
                return db;
            }
            else {
                const result = config.mongoSetting.client
                    .db(config.mongoSetting.database)
                    .collection(config.mongoSetting.collection);
                return result;
            }
        }
        else {
            throw new Error('No config or collection is defined!');
        }
    });
}
exports.getMongoCollection = getMongoCollection;
//# sourceMappingURL=get-mongo-collection.js.map