"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMongoDb = void 0;
const mongodb = require("mongodb");
let client;
let collection;
const MongoClient = mongodb.MongoClient;
/**
 * @description It keeps MongoDb connection in RAM.
 *
 * @export
 * @param {IMongoDefinition} config Configuration to mongo
 * @return {*}  {Promise<mongodb.Collection>}
 */
function getMongoDb(config) {
    return __awaiter(this, void 0, void 0, function* () {
        if (collection) {
            return collection;
        }
        else {
            try {
                const newClient = yield MongoClient.connect(config.url, config.options);
                client = newClient;
                const db = client.db(config.database);
                collection = db.collection(config.collection);
                return collection;
            }
            catch (err) {
                const logErr = {
                    error: err,
                    extraInfo: {
                        function: `${__filename}[${getMongoDb.name}]`,
                        config: config,
                    },
                };
                console.error(logErr);
                throw logErr.error;
            }
        }
    });
}
exports.getMongoDb = getMongoDb;
//# sourceMappingURL=get-mongo-db.js.map